@@ -184,25 +184,12 @@ NEWLINE_TAB = f'\n{TAB}'
 flatten_code = f'pivot_table.columns = [{NEWLINE_TAB}\'_\'.join([str(c) for c in col]).strip() if isinstance(col, tuple) else col{NEWLINE_TAB}for col in pivot_table.columns.values\n]'
 
 
-def test_transpile_initial_rename_mulitple_columns():
-    df1 = pd.DataFrame(data={'First Name': ['Nate', 'Nate'], 'Last Name': ['Rush', 'Jack']})
+def test_transpile_does_no_initial():
+    df1 = pd.DataFrame(data={'First Name': ['Nate', 'Nate'], 123: ['Rush', 'Jack'], True: ['1', '2']})
     mito = create_mito_wrapper_dfs(df1)
 
-    assert mito.transpiled_code == [
-        '# Rename headers to make them work with Mito',
-        'df1.rename(columns={\"First Name\": \"First_Name\", \"Last Name\": \"Last_Name\"}, inplace=True)',
-    ]
+    assert len(mito.transpiled_code) == 0
 
-def test_transpile_initial_rename_multiple_dfs():
-    df1 = pd.DataFrame(data={'First Name': ['Nate', 'Nate'], 'Last_Name': ['Rush', 'Jack']})
-    df2 = pd.DataFrame(data={'First_Name': ['Nate', 'Nate'], 'Last Name': ['Rush', 'Jack']})
-    mito = create_mito_wrapper_dfs(df1, df2)
-
-    assert mito.transpiled_code == [
-        '# Rename headers to make them work with Mito',
-        'df1.rename(columns={\"First Name\": \"First_Name\"}, inplace=True)',
-        'df2.rename(columns={\"Last Name\": \"Last_Name\"}, inplace=True)',
-    ]
     
 def test_transpile_reorder_column():
     df1 = pd.DataFrame(data={'A': ['aaron'], 'B': ['jon']})
@@ -241,39 +228,6 @@ def test_transpile_reorder_column_invalid():
         'df1 = df1[df1_columns]',
     ]
 
-def test_transpile_sort_ascending_valid():
-    df1 = pd.DataFrame(data={'A': [1, 2, 3, 4, 5]})
-    mito = create_mito_wrapper_dfs(df1)
-    mito.sort(0, 'A', 'ascending')
-
-    assert mito.transpiled_code == [
-        'df1 = df1.sort_values(by=\'A\', ascending=True, na_position=\'first\')',
-        'df1 = df1.reset_index(drop=True)',
-    ]
-
-def test_transpile_sort_descending_valid():
-    df1 = pd.DataFrame(data={'A': [1, 2, 3, 4, 5]})
-    mito = create_mito_wrapper_dfs(df1)
-    mito.sort(0, 'A', 'descending')
-
-    assert mito.transpiled_code == [
-        'df1 = df1.sort_values(by=\'A\', ascending=False, na_position=\'first\')',
-        'df1 = df1.reset_index(drop=True)',
-    ]
-
-def test_transpile_sort_ascending_then_descending_valid():
-    df1 = pd.DataFrame(data={'A': [1, 2, 3, 4, 5]})
-    mito = create_mito_wrapper_dfs(df1)
-    mito.sort(0, 'A', 'ascending')
-    mito.sort(0, 'A', 'descending')
-
-    assert mito.transpiled_code == [
-        'df1 = df1.sort_values(by=\'A\', ascending=True, na_position=\'first\')',
-        'df1 = df1.reset_index(drop=True)',
-        'df1 = df1.sort_values(by=\'A\', ascending=False, na_position=\'first\')',
-        'df1 = df1.reset_index(drop=True)'
-    ]
-
 def test_transpile_merge_then_sort():
     df1 = pd.DataFrame(data={'Name': ["Aaron", "Nate"], 'Number': [123, 1]})
     df2 = pd.DataFrame(data={'Name': ["Aaron", "Nate"], 'Sign': ['Gemini', "Tarus"]})
@@ -285,5 +239,4 @@ def test_transpile_merge_then_sort():
         'temp_df = df2.drop_duplicates(subset=\'Name\') # Remove duplicates so lookup merge only returns first match',
         'df3 = df1.merge(temp_df, left_on=[\'Name\'], right_on=[\'Name\'], how=\'left\', suffixes=[\'_df1\', \'_df2\'])',
         'df3 = df3.sort_values(by=\'Number\', ascending=True, na_position=\'first\')',
-        'df3 = df3.reset_index(drop=True)'
     ]
