@@ -30,6 +30,7 @@ UJ_FEEDBACKS = 'feedbacks'
 UJ_MITOSHEET_CURRENT_VERSION = 'mitosheet_current_version'
 UJ_MITOSHEET_LAST_UPGRADED_DATE = 'mitosheet_last_upgraded_date'
 UJ_MITOSHEET_LAST_FIFTY_USAGES = 'mitosheet_last_fifty_usages'
+UJ_MITOSHEET_TELEMETRY = 'mitosheet_telemetry'
 
 # This was the final version of the user.json with user_json_version == 1
 # and since we added fields to it over time, we make sure that all users 
@@ -74,7 +75,26 @@ USER_JSON_VERSION_2 = {
     UJ_MITOSHEET_LAST_FIFTY_USAGES: [datetime.today().strftime('%Y-%m-%d')]
 }
 
+USER_JSON_VERSION_3 = {
+    # The new version of the user json object
+    UJ_USER_JSON_VERSION: 3,
+    # The static id of the user
+    UJ_STATIC_USER_ID: get_random_id(),
+    # A random secret that the user can use as salt when hashing things
+    UJ_USER_SALT: get_random_id(),
+    # Email of the user
+    UJ_USER_EMAIL: '',
+    # Tours that the user has received
+    UJ_RECEIVED_TOURS: [],
+    # A list of all the feedback the user has given
+    UJ_FEEDBACKS: [],
+    UJ_MITOSHEET_CURRENT_VERSION: __version__,
+    UJ_MITOSHEET_LAST_UPGRADED_DATE: datetime.today().strftime('%Y-%m-%d'),
+    UJ_MITOSHEET_LAST_FIFTY_USAGES: [datetime.today().strftime('%Y-%m-%d')],
+    UJ_MITOSHEET_TELEMETRY: True
+}
+
 
 # This is the most up to date user json, and you must update it when
 # you add a new schema
-USER_JSON_DEFAULT = USER_JSON_VERSION_2
\ No newline at end of file
+USER_JSON_DEFAULT = USER_JSON_VERSION_3
\ No newline at end of file
